@@ -29,6 +29,7 @@ public:
     void setPosition(int x, int y);
     int extent() const { return x() + int(width()); }
     virtual void repaint();
+    static void freeFonts() { normalButtonFont = null; activeButtonFont = null; }
 
 private:
     virtual void handleButton(const XButtonEvent &button);
@@ -55,6 +56,7 @@ private:
     virtual void inputEscape(YInputLine* input);
     virtual void inputLostFocus(YInputLine* input);
     virtual void paint(Graphics &g, const YRect &r);
+    virtual void updateToolTip();
 
     int fWorkspace;
     int fDelta;
@@ -107,6 +109,7 @@ class WorkspacesPane:
 
 public:
     WorkspacesPane(YWindow *parent);
+    ~WorkspacesPane() { WorkspaceButton::freeFonts(); }
 
     virtual void repaint();
     virtual void relabelButtons();
